@@ -303,11 +303,6 @@ public:
         return libjami::switchInput(accountId, callId, input);
     }
 
-    bool switchSecondaryInput(const std::string& accountId, const std::string& conferenceId, const std::string& input)
-    {
-        return libjami::switchSecondaryInput(accountId, conferenceId, input);
-    }
-
     void playDTMF(const std::string& key) { libjami::playDTMF(key); }
 
     void startTone(const int32_t& start, const int32_t& type) { libjami::startTone(start, type); }
