@@ -216,11 +216,6 @@ public:
         return libjami::getMessageStatus(accountID, id);
     }
 
-    bool cancelMessage(const std::string& accountID, const uint64_t& id)
-    {
-        return libjami::cancelMessage(accountID, id);
-    }
-
     void setIsComposing(const std::string& accountID, const std::string& conversationUri, const bool& isWriting)
     {
         libjami::setIsComposing(accountID, conversationUri, isWriting);
