@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 
 #include <opendht/rng.h>
 
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "account_schema.h"
 #include "jami/account_const.h"
 #include "string_utils.h"
