@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "config.h"
 #endif
 
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "configurationmanager_interface.h"
 #include "noncopyable.h"
 #include "config/serializable.h"
@@ -227,8 +227,6 @@ public:
      */
     virtual im::MessageStatus getMessageStatus(uint64_t /*id*/) const { return im::MessageStatus::UNKNOWN; }
 
-    virtual bool cancelMessage(uint64_t /*id*/) { return false; }
-
     virtual bool setPushNotificationToken(const std::string& pushDeviceToken = "")
     {
         std::lock_guard lock(configurationMutex_);
