@@ -449,12 +449,8 @@ protected:
      * Constructor of a call
      * @param id Unique identifier of the call
      * @param type set definitely this call as incoming/outgoing
-     * @param details volatile details to customize the call creation
      */
-    Call(const std::shared_ptr<Account>& account,
-         const std::string& id,
-         Call::CallType type,
-         const std::map<std::string, std::string>& details = {});
+    Call(const std::shared_ptr<Account>& account, const std::string& id, Call::CallType type);
 
     // TODO all these members are not protected against multi-thread access
 
