@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 #include "callmanager_interface.h"
 #include "call_factory.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include "sip/siptransport.h"
 #include "sip/sipvoiplink.h"
@@ -206,18 +206,6 @@ isConferenceParticipant(const std::string& accountId, const std::string& callId)
     return false;
 }
 
-void
-startSmartInfo(uint32_t refreshTimeMs)
-{
-    JAMI_WARNING("startSmartInfo is deprecated and does nothing.");
-}
-
-void
-stopSmartInfo()
-{
-    JAMI_WARNING("stopSmartInfo is deprecated and does nothing.");
-}
-
 bool
 addParticipant(const std::string& accountId,
                const std::string& callId,
@@ -441,13 +429,6 @@ switchInput(const std::string& accountId, const std::string& callId, const std::
     return false;
 }
 
-bool
-switchSecondaryInput(const std::string& accountId, const std::string& confId, const std::string& resource)
-{
-    JAMI_ERR("Use requestMediaChange");
-    return false;
-}
-
 void
 sendTextMessage(const std::string& accountId,
                 const std::string& callId,
