@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include "audio/audiolayer.h"
 #include "system_codec_container.h"
 #include "account_const.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "audio/ringbufferpool.h"
 #include "connectivity/security/tlsvalidator.h"
 
@@ -94,8 +94,7 @@ validateCertificate(const std::string& accountId, const std::string& certificate
 {
     try {
         if (const auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId))
-            return TlsValidator {acc->certStore(), acc->certStore().getCertificate(certificate)}
-                .getSerializedChecks();
+            return TlsValidator {acc->certStore(), acc->certStore().getCertificate(certificate)}.getSerializedChecks();
     } catch (const std::runtime_error& e) {
         JAMI_WARN("Certificate loading failed: %s", e.what());
     }
@@ -111,8 +110,7 @@ validateCertificatePath(const std::string& accountId,
 {
     try {
         if (const auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId))
-            return TlsValidator {acc->certStore(), certificate, privateKey, privateKeyPass, caList}
-                .getSerializedChecks();
+            return TlsValidator {acc->certStore(), certificate, privateKey, privateKeyPass, caList}.getSerializedChecks();
     } catch (const std::runtime_error& e) {
         JAMI_WARN("Certificate loading failed: %s", e.what());
         return {{Certificate::ChecksNames::EXIST, Certificate::CheckValuesNames::FAILED}};
@@ -125,8 +123,7 @@ getCertificateDetails(const std::string& accountId, const std::string& certifica
 {
     try {
         if (const auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId))
-            return TlsValidator {acc->certStore(), acc->certStore().getCertificate(certificate)}
-                .getSerializedDetails();
+            return TlsValidator {acc->certStore(), acc->certStore().getCertificate(certificate)}.getSerializedDetails();
     } catch (const std::runtime_error& e) {
         JAMI_WARN("Certificate loading failed: %s", e.what());
     }
@@ -140,8 +137,7 @@ getCertificateDetailsPath(const std::string& accountId,
                           const std::string& privateKeyPassword)
 {
     try {
-        auto crt = std::make_shared<dht::crypto::Certificate>(
-            jami::fileutils::loadFile(certificate));
+        auto crt = std::make_shared<dht::crypto::Certificate>(jami::fileutils::loadFile(certificate));
         if (const auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId)) {
             TlsValidator validator {acc->certStore(), certificate, privateKey, privateKeyPassword};
             acc->certStore().pinCertificate(validator.getCertificate(), false);
@@ -197,16 +193,14 @@ pinRemoteCertificate(const std::string& accountId, const std::string& certId)
 {
     if (auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId)) {
         acc->dht()->findCertificate(dht::InfoHash(certId),
-                                    [](const std::shared_ptr<dht::crypto::Certificate>& crt) {});
+                                    [](const std::shared_ptr<dht::crypto::Certificate>& /*crt*/) {});
         return true;
     }
     return false;
 }
 
 bool
-setCertificateStatus(const std::string& accountId,
-                     const std::string& certId,
-                     const std::string& ststr)
+setCertificateStatus(const std::string& accountId, const std::string& certId, const std::string& ststr)
 {
     try {
         if (auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId)) {
@@ -321,12 +315,6 @@ getMessageStatus(const std::string& accountId, uint64_t messageId)
     return jami::Manager::instance().getMessageStatus(accountId, messageId);
 }
 
-bool
-cancelMessage(const std::string& accountId, uint64_t messageId)
-{
-    return {};
-}
-
 void
 setIsComposing(const std::string& accountId, const std::string& conversationUri, bool isWriting)
 {
@@ -419,9 +407,7 @@ getKnownRingDevices(const std::string& accountId)
 }
 
 bool
-changeAccountPassword(const std::string& accountId,
-                      const std::string& password_old,
-                      const std::string& password_new)
+changeAccountPassword(const std::string& accountId, const std::string& password_old, const std::string& password_new)
 {
     if (auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId))
         return acc->changeArchivePassword(password_old, password_new);
@@ -486,9 +472,7 @@ discardTrustRequest(const std::string& accountId, const std::string& from)
 }
 
 void
-sendTrustRequest(const std::string& accountId,
-                 const std::string& to,
-                 const std::vector<uint8_t>& payload)
+sendTrustRequest(const std::string& accountId, const std::string& to, const std::vector<uint8_t>& payload)
 {
     if (auto acc = jami::Manager::instance().getAccount<jami::JamiAccount>(accountId))
         acc->sendTrustRequest(to, payload);
@@ -548,8 +532,7 @@ getAccountList()
 std::vector<unsigned>
 getCodecList()
 {
-    std::vector<unsigned> list {
-        jami::getSystemCodecContainer()->getSystemCodecInfoIdList(jami::MEDIA_ALL)};
+    std::vector<unsigned> list {jami::getSystemCodecContainer()->getSystemCodecInfoIdList(jami::MEDIA_ALL)};
     if (list.empty())
         jami::emitSignal<ConfigurationSignal::Error>(CODECS_NOT_LOADED);
     return list;
@@ -571,9 +554,7 @@ getSupportedCiphers(const std::string& accountId)
 }
 
 bool
-setCodecDetails(const std::string& accountId,
-                const unsigned& codecId,
-                const std::map<std::string, std::string>& details)
+setCodecDetails(const std::string& accountId, const unsigned& codecId, const std::map<std::string, std::string>& details)
 {
     auto acc = jami::Manager::instance().getAccount(accountId);
     if (!acc) {
@@ -699,12 +680,6 @@ setAudioInputDevice(int32_t index)
     return jami::Manager::instance().setAudioDevice(index, AudioDeviceType::CAPTURE);
 }
 
-void
-startAudio()
-{
-    jami::Manager::instance().startAudio();
-}
-
 void
 setAudioRingtoneDevice(int32_t index)
 {
@@ -749,6 +724,30 @@ setNoiseSuppressState(const std::string& state)
     jami::Manager::instance().setNoiseSuppressState(state);
 }
 
+std::string
+getEchoCancellationState()
+{
+    return jami::Manager::instance().getEchoCancellationState();
+}
+
+void
+setEchoCancellationState(const std::string& state)
+{
+    jami::Manager::instance().setEchoCancellationState(state);
+}
+
+bool
+getVoiceActivityDetectionState()
+{
+    return jami::Manager::instance().getVoiceActivityDetectionState();
+}
+
+void
+setVoiceActivityDetectionState(bool state)
+{
+    jami::Manager::instance().setVoiceActivityDetectionState(state);
+}
+
 bool
 isAgcEnabled()
 {
@@ -838,13 +837,13 @@ setHistoryLimit(int32_t days)
 int32_t
 getRingingTimeout()
 {
-    return jami::Manager::instance().getRingingTimeout();
+    return jami::Manager::instance().getRingingTimeout().count();
 }
 
 void
 setRingingTimeout(int32_t timeout)
 {
-    jami::Manager::instance().setRingingTimeout(timeout);
+    jami::Manager::instance().setRingingTimeout(std::chrono::seconds(timeout));
 }
 
 std::vector<std::string>
@@ -1003,13 +1002,11 @@ getCredentials(const std::string& accountId)
 }
 
 void
-setCredentials(const std::string& accountId,
-               const std::vector<std::map<std::string, std::string>>& details)
+setCredentials(const std::string& accountId, const std::vector<std::map<std::string, std::string>>& details)
 {
     if (auto sipaccount = jami::Manager::instance().getAccount<SIPAccount>(accountId)) {
         sipaccount->doUnregister();
-        sipaccount->editConfig(
-            [&](jami::SipAccountConfig& config) { config.setCredentials(details); });
+        sipaccount->editConfig([&](jami::SipAccountConfig& config) { config.setCredentials(details); });
         sipaccount->loadConfig();
         if (sipaccount->isEnabled())
             sipaccount->doRegister();
@@ -1039,17 +1036,15 @@ connectivityChanged()
 bool
 lookupName(const std::string& account, const std::string& nameserver, const std::string& name)
 {
-#ifdef ENABLE_NAMESERVER
     if (account.empty()) {
-        auto cb = [name](const std::string& regName,
-                         const std::string& address,
-                         jami::NameDirectory::Response response) {
-            jami::emitSignal<libjami::ConfigurationSignal::RegisteredNameFound>("",
-                                                                                name,
-                                                                                (int) response,
-                                                                                address,
-                                                                                regName);
-        };
+        auto cb =
+            [name](const std::string& regName, const std::string& address, jami::NameDirectory::Response response) {
+                jami::emitSignal<libjami::ConfigurationSignal::RegisteredNameFound>("",
+                                                                                    name,
+                                                                                    (int) response,
+                                                                                    address,
+                                                                                    regName);
+            };
         if (nameserver.empty())
             jami::NameDirectory::lookupUri(name, "", cb);
         else
@@ -1059,29 +1054,31 @@ lookupName(const std::string& account, const std::string& nameserver, const std:
         acc->lookupName(name);
         return true;
     }
-#endif
+    JAMI_ERROR("lookupName: Unknown account: {}", account);
     return false;
 }
 
 bool
 lookupAddress(const std::string& account, const std::string& nameserver, const std::string& address)
 {
-#ifdef ENABLE_NAMESERVER
     if (account.empty()) {
         jami::NameDirectory::instance(nameserver)
             .lookupAddress(address,
                            [address](const std::string& regName,
                                      const std::string& addr,
                                      jami::NameDirectory::Response response) {
-                               jami::emitSignal<libjami::ConfigurationSignal::RegisteredNameFound>(
-                                   "", address, (int) response, addr, regName);
+                               jami::emitSignal<libjami::ConfigurationSignal::RegisteredNameFound>("",
+                                                                                                   address,
+                                                                                                   (int) response,
+                                                                                                   addr,
+                                                                                                   regName);
                            });
         return true;
     } else if (auto acc = jami::Manager::instance().getAccount<JamiAccount>(account)) {
         acc->lookupAddress(address);
         return true;
     }
-#endif
+    JAMI_ERROR("lookupAddress: Unknown account: {}", account);
     return false;
 }
 
@@ -1095,17 +1092,13 @@ searchUser(const std::string& account, const std::string& query)
 }
 
 bool
-registerName(const std::string& account,
-             const std::string& name,
-             const std::string& scheme,
-             const std::string& password)
+registerName(const std::string& account, const std::string& name, const std::string& scheme, const std::string& password)
 {
-#ifdef ENABLE_NAMESERVER
     if (auto acc = jami::Manager::instance().getAccount<JamiAccount>(account)) {
         acc->registerName(name, scheme, password);
         return true;
     }
-#endif
+    JAMI_ERROR("registerName: Unknown account: {}", account);
     return false;
 }
 
