@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "base64.h"
 #include "fileutils.h"
 #include "manager.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include <mutex>
 #include <cstdlib> // mkstemp
@@ -193,7 +193,7 @@ IncomingFile::process()
         JAMI_ERROR("{} bytes received after IncomingFile destruction.", len);
         return (ssize_t) -1;
     });
-    channel_->onShutdown([w = weak_from_this()](const std::error_code& sock_ec) {
+    channel_->onShutdown([w = weak_from_this()](const std::error_code& /*error_code*/) {
         auto shared = w.lock();
         if (!shared)
             return;
