@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -103,6 +103,12 @@ LIBJAMI_PUBLIC bool hangUpConference(const std::string& accountId, const std::st
 LIBJAMI_PUBLIC bool holdConference(const std::string& accountId, const std::string& confId);
 LIBJAMI_PUBLIC bool unholdConference(const std::string& accountId, const std::string& confId);
 LIBJAMI_PUBLIC std::vector<std::string> getConferenceList(const std::string& accountId);
+/// NOTE: Despite its name, this returns the list of call IDs (subcalls) in the conference,
+/// not the actual participant URIs. This naming is historical.
+/// However the URIs are accessible from the confInfos structure passed with the OnConferenceInfosUpdated signal.
+/// It should be noted that as of February 2026, confInfos is primarily generated by the VideoMixer
+/// based on active RTP streams, which means it can be unreliable during state transitions
+/// (e.g., camera activation/deactivation) where streams are temporarily missing.
 LIBJAMI_PUBLIC std::vector<std::string> getParticipantList(const std::string& accountId, const std::string& confId);
 LIBJAMI_PUBLIC std::string getConferenceId(const std::string& accountId, const std::string& callId);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getConferenceDetails(const std::string& accountId,
@@ -151,10 +157,6 @@ LIBJAMI_PUBLIC void raiseHand(const std::string& accountId,
                               const std::string& deviceId,
                               const bool& state);
 
-/* Statistic related methods */
-LIBJAMI_PUBLIC void startSmartInfo(uint32_t refreshTimeMs);
-LIBJAMI_PUBLIC void stopSmartInfo();
-
 /* File Playback methods */
 LIBJAMI_PUBLIC bool startRecordedFilePlayback(const std::string& filepath);
 LIBJAMI_PUBLIC void stopRecordedFilePlayback();
@@ -170,9 +172,6 @@ LIBJAMI_PUBLIC void playDTMF(const std::string& key);
 LIBJAMI_PUBLIC void startTone(int32_t start, int32_t type);
 
 LIBJAMI_PUBLIC bool switchInput(const std::string& accountId, const std::string& callId, const std::string& resource);
-LIBJAMI_PUBLIC bool switchSecondaryInput(const std::string& accountId,
-                                         const std::string& confId,
-                                         const std::string& resource);
 
 /* Instant messaging */
 LIBJAMI_PUBLIC void sendTextMessage(const std::string& accountId,
@@ -282,11 +281,6 @@ struct LIBJAMI_PUBLIC CallSignal
         constexpr static const char* name = "AudioMuted";
         using cb_type = void(const std::string&, bool);
     };
-    struct LIBJAMI_PUBLIC SmartInfo
-    {
-        constexpr static const char* name = "SmartInfo";
-        using cb_type = void(const std::map<std::string, std::string>&);
-    };
     struct LIBJAMI_PUBLIC ConnectionUpdate
     {
         constexpr static const char* name = "ConnectionUpdate";
