@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -96,7 +96,6 @@ LIBJAMI_PUBLIC uint64_t sendAccountTextMessage(const std::string& accountId,
                                                const std::string& to,
                                                const std::map<std::string, std::string>& payloads,
                                                int32_t flags);
-LIBJAMI_PUBLIC bool cancelMessage(const std::string& accountId, uint64_t message);
 LIBJAMI_PUBLIC std::vector<Message> getLastMessages(const std::string& accountId, const uint64_t& base_timestamp);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getNearbyPeers(const std::string& accountId);
 LIBJAMI_PUBLIC void updateProfile(const std::string& accountId,
@@ -127,7 +126,6 @@ LIBJAMI_PUBLIC std::vector<std::string> getAudioPluginList();
 LIBJAMI_PUBLIC void setAudioPlugin(const std::string& audioPlugin);
 LIBJAMI_PUBLIC std::vector<std::string> getAudioOutputDeviceList();
 LIBJAMI_PUBLIC void setAudioOutputDevice(int32_t index);
-LIBJAMI_PUBLIC void startAudio();
 LIBJAMI_PUBLIC void setAudioInputDevice(int32_t index);
 LIBJAMI_PUBLIC void setAudioRingtoneDevice(int32_t index);
 LIBJAMI_PUBLIC std::vector<std::string> getAudioInputDeviceList();
