@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include "jamidht/conversation_module.h"
 #include "manager.h"
 #include "jamidht/auth_channel_handler.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 
 #include <dhtnet/multiplexed_socket.h>
 #include <dhtnet/channel_utils.h>
@@ -588,7 +588,7 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
                                                                              DeviceAuthState::TOKEN_AVAILABLE),
                                                                          info);
 
-        ctx->linkDevCtx->tempConnMgr.onICERequest([wctx = std::weak_ptr(ctx)](const DeviceId& deviceId) {
+        ctx->linkDevCtx->tempConnMgr.onICERequest([wctx = std::weak_ptr(ctx)](const DeviceId& /*deviceId*/) {
             if (auto ctx = wctx.lock()) {
                 emitSignal<libjami::ConfigurationSignal::DeviceAuthStateChanged>(ctx->accountId,
                                                                                  static_cast<uint8_t>(
@@ -600,7 +600,7 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
         });
 
         ctx->linkDevCtx->tempConnMgr.onChannelRequest(
-            [wthis, ctx](const std::shared_ptr<dht::crypto::Certificate>& cert, const std::string& name) {
+            [wthis, ctx](const std::shared_ptr<dht::crypto::Certificate>& /*cert*/, const std::string& name) {
                 std::string_view url(name);
                 if (!starts_with(url, CHANNEL_SCHEME)) {
                     JAMI_WARNING("[LinkDevice] Temporary connection manager received invalid scheme: {}", name);
@@ -623,9 +623,9 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
 
         ctx->linkDevCtx->tempConnMgr.onConnectionReady([ctx,
                                                         accountScheme,
-                                                        wthis](const DeviceId& deviceId,
+                                                        wthis](const DeviceId& /*deviceId*/,
                                                                const std::string& name,
-                                                               std::shared_ptr<dhtnet::ChannelSocket> socket) {
+                                                               const std::shared_ptr<dhtnet::ChannelSocket>& socket) {
             if (!socket) {
                 JAMI_WARNING("[LinkDevice] Temporary connection manager received invalid socket.");
                 if (ctx->timeout)
@@ -665,7 +665,7 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
                 }
             });
 
-            socket->onShutdown([ctx, name, wthis](const std::error_code& ec) {
+            socket->onShutdown([ctx, name, wthis](const std::error_code& /*error_code*/) {
                 JAMI_WARNING("[LinkDevice] Temporary connection manager closing socket: {}", name);
                 if (ctx->timeout)
                     ctx->timeout->cancel();
@@ -879,13 +879,12 @@ ArchiveAccountManager::addDevice(const std::string& uriProvided,
         channelHandler->connect(dht::InfoHash(peerTempAcc),
                                 channelName,
                                 [onConnect](std::shared_ptr<dhtnet::ChannelSocket> socket,
-                                            const dht::InfoHash& infoHash) { onConnect(std::move(socket)); });
+                                            const dht::InfoHash& /*infoHash*/) { onConnect(std::move(socket)); });
     } else {
         channelHandler->connect(dht::PkId(peerTempAcc),
                                 channelName,
-                                [onConnect](std::shared_ptr<dhtnet::ChannelSocket> socket, const dht::PkId& infoHash) {
-                                    onConnect(std::move(socket));
-                                });
+                                [onConnect](std::shared_ptr<dhtnet::ChannelSocket> socket,
+                                            const dht::PkId& /*infoHash*/) { onConnect(std::move(socket)); });
     }
 
     runOnMainThread([token, id = accountId_] {
@@ -941,7 +940,7 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
     });
 
     JAMI_DEBUG("[LinkDevice] SOURCE: Creating callbacks.");
-    ctx->addDeviceCtx->channel->onShutdown([ctx, w = weak()](const std::error_code& ec) {
+    ctx->addDeviceCtx->channel->onShutdown([ctx, w = weak()](const std::error_code& /*error_code*/) {
         JAMI_DEBUG("[LinkDevice] SOURCE: Shutdown with state {}... xfer {}uccessful",
                    ctx->addDeviceCtx->formattedAuthState(),
                    ctx->addDeviceCtx->archiveTransferredWithoutFailure ? "s" : "uns");
@@ -1221,7 +1220,7 @@ ArchiveAccountManager::onArchiveLoaded(AuthContext& ctx, AccountArchive&& a, boo
     }
 
     auto receipt = makeReceipt(a.id, *deviceCertificate, ethAccount);
-    auto receiptSignature = a.id.first->sign({receipt.first.begin(), receipt.first.end()});
+    auto receiptSignature = a.id.first->sign(receipt.first);
 
     auto info = std::make_unique<AccountInfo>();
     auto pk = usePreviousIdentity ? ctx.credentials->updateIdentity.first : ctx.key.get();
@@ -1325,28 +1324,6 @@ ArchiveAccountManager::syncDevices()
     onSyncData_(info_->contacts->getSyncData());
 }
 
-void
-ArchiveAccountManager::startSync(const OnNewDeviceCb& cb, const OnDeviceAnnouncedCb& dcb, bool publishPresence)
-{
-    AccountManager::startSync(std::move(cb), std::move(dcb), publishPresence);
-
-    dht_->listen<DeviceSync>(dht::InfoHash::get("inbox:" + info_->devicePk->getId().toString()), [this](DeviceSync&& sync) {
-        // Received device sync data.
-        // check device certificate
-        findCertificate(sync.from, [this, sync](const std::shared_ptr<dht::crypto::Certificate>& cert) mutable {
-            if (!cert or cert->getId() != sync.from) {
-                JAMI_WARNING("[Account {}] Unable to find certificate for device {}", accountId_, sync.from.toString());
-                return;
-            }
-            if (not foundAccountDevice(cert))
-                return;
-            onSyncData(std::move(sync));
-        });
-
-        return true;
-    });
-}
-
 AccountArchive
 ArchiveAccountManager::readArchive(std::string_view scheme, const std::string& pwd) const
 {
