@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ void
 ConversationChannelHandler::connect(const DeviceId& deviceId,
                                     const std::string& channelName,
                                     ConnectCb&& cb,
-                                    const std::string& connectionType,
-                                    bool forceNewConnection)
+                                    const std::string& /*connectionType*/,
+                                    bool /*forceNewConnection*/)
 {
     connectionManager_.connectDevice(deviceId, "git://" + deviceId.toString() + "/" + channelName, std::move(cb));
 }
