@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
  */
 #pragma once
 
-#include "scheduled_executor.h"
 #include "jamidht/account_manager.h"
 #include "jamidht/conversation.h"
 #include "jamidht/conversationrepository.h"
@@ -240,13 +239,7 @@ public:
      * @param n                 Max interactions to load
      * @return id of the operation
      */
-    uint32_t loadConversationMessages(const std::string& conversationId,
-                                      const std::string& fromMessage = "",
-                                      size_t n = 0);
     uint32_t loadConversation(const std::string& conversationId, const std::string& fromMessage = "", size_t n = 0);
-    uint32_t loadConversationUntil(const std::string& conversationId,
-                                   const std::string& fromMessage,
-                                   const std::string& to);
     uint32_t loadSwarmUntil(const std::string& conversationId,
                             const std::string& fromMessage,
                             const std::string& toMessage);
@@ -307,7 +300,7 @@ public:
      * @param memberUri
      * @param deviceId
      */
-    bool needsSyncingWith(const std::string& memberUri, const std::string& deviceId) const;
+    bool needsSyncingWith(const std::string& memberUri) const;
 
     /**
      * Notify that a peer fetched a commit
