@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,31 +17,15 @@
 #pragma once
 #include "def.h"
 #include "vcard.h"
+#include "git_def.h"
 
 #include <opendht/default_types.h>
-#include <git2.h>
 
 #include <optional>
 #include <memory>
 #include <string>
 #include <vector>
 
-using GitPackBuilder = std::unique_ptr<git_packbuilder, decltype(&git_packbuilder_free)>;
-using GitRepository = std::unique_ptr<git_repository, decltype(&git_repository_free)>;
-using GitRevWalker = std::unique_ptr<git_revwalk, decltype(&git_revwalk_free)>;
-using GitCommit = std::unique_ptr<git_commit, decltype(&git_commit_free)>;
-using GitAnnotatedCommit = std::unique_ptr<git_annotated_commit, decltype(&git_annotated_commit_free)>;
-using GitIndex = std::unique_ptr<git_index, decltype(&git_index_free)>;
-using GitTree = std::unique_ptr<git_tree, decltype(&git_tree_free)>;
-using GitRemote = std::unique_ptr<git_remote, decltype(&git_remote_free)>;
-using GitReference = std::unique_ptr<git_reference, decltype(&git_reference_free)>;
-using GitSignature = std::unique_ptr<git_signature, decltype(&git_signature_free)>;
-using GitObject = std::unique_ptr<git_object, decltype(&git_object_free)>;
-using GitDiff = std::unique_ptr<git_diff, decltype(&git_diff_free)>;
-using GitDiffStats = std::unique_ptr<git_diff_stats, decltype(&git_diff_stats_free)>;
-using GitIndexConflictIterator
-    = std::unique_ptr<git_index_conflict_iterator, decltype(&git_index_conflict_iterator_free)>;
-
 namespace jami {
 
 using DeviceId = dht::PkId;
@@ -200,6 +184,15 @@ public:
      */
     bool fetch(const std::string& remoteDeviceId);
 
+    /**
+     * Merge the history of the conversation with another peer
+     * @param uri                    The peer uri
+     * @param disconnectFromPeerCb   Callback to disconnect from peer when banning
+     * @return                       A vector of media maps representing the merged history
+     */
+    std::vector<std::map<std::string, std::string>> mergeHistory(
+        const std::string& uri, std::function<void(const std::string&)>&& disconnectFromPeerCb = {});
+
     /**
      * Retrieve remote head. Can be useful after a fetch operation
      * @param remoteDeviceId        The remote name
@@ -258,14 +251,6 @@ public:
      */
     std::pair<bool, std::string> merge(const std::string& merge_id, bool force = false);
 
-    /**
-     * Get the common parent between two branches
-     * @param from  The first branch
-     * @param to    The second branch
-     * @return the common parent
-     */
-    std::string mergeBase(const std::string& from, const std::string& to) const;
-
     /**
      * Get current diff stats between two commits
      * @param oldId     Old commit
