@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -247,8 +247,12 @@ RingBufferPool::unBindAllHalfDuplexOut(const std::string& ringbufferId)
 void
 RingBufferPool::unBindAllHalfDuplexIn(const std::string& sourceBufferId)
 {
+    auto ringBuffer = getRingBuffer(sourceBufferId);
+    if (not ringBuffer) {
+        JAMI_ERROR("No ringbuffer associated to id '{}'", sourceBufferId);
+        return;
+    }
     std::lock_guard lk(stateLock_);
-    const std::shared_ptr<RingBuffer>& ringBuffer = getRingBuffer(sourceBufferId);
     const std::vector<std::string>& subscribers = ringBuffer->getSubscribers();
     for (const auto& subscriber : subscribers) {
         removeReaderFromRingBuffer(ringBuffer, subscriber);
