@@ -40,6 +40,7 @@
 #include <thread> // hardware_concurrency
 #include <chrono>
 #include <algorithm>
+#include <asio/steady_timer.hpp>
 
 namespace jami {
 
@@ -57,6 +58,10 @@ MediaDemuxer::MediaDemuxer()
 
 MediaDemuxer::~MediaDemuxer()
 {
+    if (streamInfoTimer_) {
+        streamInfoTimer_->cancel();
+        streamInfoTimer_.reset();
+    }
     if (inputCtx_)
         avformat_close_input(&inputCtx_);
     av_dict_free(&options_);
@@ -213,15 +218,36 @@ MediaDemuxer::seekFrame(int, int64_t timestamp)
 }
 
 void
-MediaDemuxer::findStreamInfo()
+MediaDemuxer::findStreamInfo(bool videoStream)
 {
     if (not streamInfoFound_) {
         inputCtx_->max_analyze_duration = 30 * AV_TIME_BASE;
-        int err;
-        if ((err = avformat_find_stream_info(inputCtx_, nullptr)) < 0) {
-            JAMI_ERR() << "Unable to find stream info: " << libav_utils::getError(err);
+        if (videoStream && keyFrameRequestCb_) {
+            if (!streamInfoTimer_)
+                streamInfoTimer_ = std::make_unique<asio::steady_timer>(*Manager::instance().ioContext());
+            streamInfoTimer_->expires_after(std::chrono::milliseconds(1500));
+            streamInfoTimer_->async_wait([weak = weak_from_this()](const std::error_code& ec) {
+                if (ec)
+                    return;
+                if (auto self = weak.lock()) {
+                    if (!self->streamInfoFound_) {
+                        JAMI_LOG("findStreamInfo: 1500ms elapsed, requesting keyframe to aid probing");
+                        if (self->keyFrameRequestCb_)
+                            self->keyFrameRequestCb_();
+                    }
+                }
+            });
+        }
+
+        int err = avformat_find_stream_info(inputCtx_, nullptr);
+        if (err < 0) {
+            JAMI_ERROR("Unable to find stream info: {}", libav_utils::getError(err));
         }
         streamInfoFound_ = true;
+        if (streamInfoTimer_) {
+            streamInfoTimer_->cancel();
+            streamInfoTimer_.reset();
+        }
     }
 }
 
@@ -262,6 +288,12 @@ MediaDemuxer::setFileFinishedCb(std::function<void(bool)> cb)
     fileFinishedCb_ = std::move(cb);
 }
 
+void
+MediaDemuxer::setKeyFrameRequestCb(std::function<void()> cb)
+{
+    keyFrameRequestCb_ = std::move(cb);
+}
+
 void
 MediaDemuxer::clearFrames()
 {
@@ -497,10 +529,16 @@ MediaDecoder::setIOContext(MediaIOHandle* ioctx)
     demuxer_->setIOContext(ioctx);
 }
 
+void
+MediaDecoder::setKeyFrameRequestCb(std::function<void()> cb)
+{
+    demuxer_->setKeyFrameRequestCb(std::move(cb));
+}
+
 int
 MediaDecoder::setup(AVMediaType type)
 {
-    demuxer_->findStreamInfo();
+    demuxer_->findStreamInfo(type == AVMEDIA_TYPE_VIDEO);
     auto stream = demuxer_->selectStream(type);
     if (stream < 0) {
         JAMI_ERR("No stream found for type %i", static_cast<int>(type));
