@@ -391,10 +391,7 @@ SocketPair::waitForData()
             }
 
             // work with system socket
-            struct pollfd p[2] = {
-                {rtpHandle_,  POLLIN, 0},
-                {rtcpHandle_, POLLIN, 0}
-            };
+            struct pollfd p[2] = {{rtpHandle_, POLLIN, 0}, {rtcpHandle_, POLLIN, 0}};
             ret = poll(p, 2, NET_POLL_TIMEOUT);
             if (ret > 0) {
                 ret = 0;
