@@ -35,11 +35,9 @@ typedef struct
     enum AVPixelFormat pixfmt;
 } ios_fmt;
 
-static const std::array<ios_fmt, 4> ios_formats {
-    ios_fmt {"RGBA",    AV_PIX_FMT_RGBA   },
-     ios_fmt {"BGRA",    AV_PIX_FMT_BGRA   },
-     ios_fmt {"YUV420P", AV_PIX_FMT_YUV420P}
-};
+static const std::array<ios_fmt, 4> ios_formats {ios_fmt {"RGBA", AV_PIX_FMT_RGBA},
+                                                 ios_fmt {"BGRA", AV_PIX_FMT_BGRA},
+                                                 ios_fmt {"YUV420P", AV_PIX_FMT_YUV420P}};
 
 class VideoDeviceImpl
 {
