@@ -1,5 +1,5 @@
 ﻿/*
- *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2026 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@
 #include "config/yamlparser.h"
 #include "logger.h"
 #include "manager.h"
-#include "client/ring_signal.h"
+#include "client/jami_signal.h"
 #include "jami/account_const.h"
 
 #ifdef ENABLE_VIDEO
@@ -292,12 +292,11 @@ SIPAccount::newOutgoingCall(std::string_view toUrl, const std::vector<libjami::M
     const bool created = sdp.createOffer(MediaAttribute::buildMediaAttributesList(mediaList, isSrtpEnabled()));
 
     if (created) {
-        std::weak_ptr<SIPCall> weak_call = call;
-        manager.scheduler().run([this, weak_call] {
+        runOnMainThread([this, weak_call = std::weak_ptr(call)] {
             if (auto call = weak_call.lock()) {
                 if (not SIPStartCall(call)) {
-                    JAMI_ERR("Unable to send outgoing INVITE request for new call");
-                    call->onFailure();
+                    JAMI_ERROR("Unable to send outgoing INVITE request for new call");
+                    call->onFailure(PJSIP_SC_INTERNAL_SERVER_ERROR);
                 }
             }
             return false;
