@@ -1,7 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2021-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,8 +19,6 @@
 
 #include "lrcinstance.h"
 #include "qtutils.h"
-#include "mainapplication.h"
-
 #include "pttlistener.h"
 
 #include <QAbstractListModel>
@@ -139,12 +135,12 @@ public:
     Q_INVOKABLE QVariant overflowHiddenModel();
     Q_INVOKABLE QVariant pendingConferenceesModel();
 
-    Q_INVOKABLE void registerFilter(QQuickWindow* object, QQuickItem* item);
-    Q_INVOKABLE void unregisterFilter(QQuickWindow* object, QQuickItem* item);
+    Q_INVOKABLE void setEventFilterActive(QObject* object, QQuickItem* item, bool isActive);
     bool eventFilter(QObject* object, QEvent* event) override;
 
 Q_SIGNALS:
     void mouseMoved(QQuickItem* item);
+    void focusKeyPressed();
     void pttKeyPressed();
     void pttKeyReleased();
 
