@@ -1,7 +1,5 @@
 /*
- * Copyright (C) 2019-2023 Savoir-faire Linux Inc.
- * Author: Yang Wang   <yang.wang@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2019-2026 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,8 +56,6 @@ CurrentAccountToMigrate::CurrentAccountToMigrate(LRCInstance* instance, QObject*
             &CurrentAccountToMigrate::slotAccountRemoved);
 }
 
-CurrentAccountToMigrate::~CurrentAccountToMigrate() {}
-
 void
 CurrentAccountToMigrate::removeCurrentAccountToMigrate()
 {
@@ -133,4 +129,4 @@ CurrentAccountToMigrate::slotAccountRemoved(const QString& accountId)
         Q_EMIT allMigrationsFinished();
     else
         Q_EMIT currentAccountToMigrateRemoved();
-}
\ No newline at end of file
+}
