@@ -1,5 +1,5 @@
 /****************************************************************************
- *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
+ *   Copyright (C) 2017-2026 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -157,6 +157,12 @@ CallbacksHandler::CallbacksHandler(const Lrc& parent)
             &CallbacksHandler::slotMediaChangeRequested,
             Qt::QueuedConnection);
 
+    connect(&CallManager::instance(),
+            &CallManagerInterface::incomingCall,
+            this,
+            &CallbacksHandler::slotIncomingCall,
+            Qt::QueuedConnection);
+
     connect(&CallManager::instance(),
             &CallManagerInterface::callStateChanged,
             this,
@@ -460,6 +466,15 @@ CallbacksHandler::slotMediaChangeRequested(const QString& accountId,
     Q_EMIT mediaChangeRequested(accountId, callId, mediaList);
 }
 
+void
+CallbacksHandler::slotIncomingCall(const QString& accountId,
+                                   const QString& callId,
+                                   const QString& from,
+                                   const VectorMapStringString& mediaList)
+{
+    Q_EMIT incomingCall(accountId, callId, from, mediaList);
+}
+
 void
 CallbacksHandler::slotCallStateChanged(const QString& accountId, const QString& callId, const QString& state, int code)
 {
@@ -521,7 +536,7 @@ CallbacksHandler::slotIncomingMessage(const QString& accountId,
     for (auto& e : interaction.toStdMap()) {
         if (e.first.contains("x-ring/ring.profile.vcard")) {
             auto decodedHead = QUrl::fromPercentEncoding(e.first.toLatin1());
-            QRegularExpression re("x-ring/ring.profile.vcard;id=([A-z0-9]+),part=([0-9]+),of=([0-9]+)");
+            static const QRegularExpression re("x-ring/ring.profile.vcard;id=([A-z0-9]+),part=([0-9]+),of=([0-9]+)");
             auto match = re.match(decodedHead);
 
             if (!match.hasMatch())
